@@ -3,7 +3,7 @@ package Plack;
 use strict;
 use warnings;
 use 5.008_001;
-our $VERSION = '0.99_24';
+our $VERSION = '0.99_75';
 $VERSION = eval $VERSION;
 
 1;
@@ -15,9 +15,10 @@ Plack - Perl Superglue for Web frameworks and Web Servers (PSGI toolkit)
 
 =head1 DESCRIPTION
 
-Plack is a set of tools for using PSGI stack. It contains middleware
-components, a reference server and utilities for Web application
-frameworks. Plack is like Ruby's Rack or Python's Paste for WSGI.
+Plack is a set of tools for using the PSGI stack. It contains
+middleware components, a reference server and utilities for Web
+application frameworks. Plack is like Ruby's Rack or Python's Paste
+for WSGI.
 
 See L<PSGI> for the PSGI specification and L<PSGI::FAQ> to know what
 PSGI and Plack are and why we need them.
@@ -27,16 +28,22 @@ PSGI and Plack are and why we need them.
 =head2 Plack::Handler
 
 L<Plack::Handler> and its subclasses contains adapters for web
-servers. We have adapters for Standalone, CGI, FCGI, Apache, AnyEvent,
-Coro, Danga::Socket and many server environments that you can run PSGI
-applications on.
+servers. We have adapters for the built-in standalone web server
+L<HTTP::Server::PSGI>, L<CGI|Plack::Handler::CGI>,
+L<FCGI|Plack::Handler::FCGI>, L<Apache1|Plack::Handler::Apache1>,
+L<Apache2|Plack::Handler::Apache2> and
+L<HTTP::Server::Simple|Plack::Handler::HTTP::Server::Simple> included
+in the core Plack distribution.
+
+There are also many HTTP server implementations on CPAN that has Plack
+handlers.
 
 See L<Plack::Handler> how to write your own adapters.
 
 =head2 Plack::Loader
 
-L<Plack::Loader> is a loader to load one of Plack::Server adapters and
-run PSGI application code reference with it.
+L<Plack::Loader> is a loader to load one of L<Plack::Handler> adapters
+and run PSGI application code reference with it.
 
 =head2 Plack::Util
 
@@ -67,7 +74,7 @@ as:
   my $app = sub { MyApp->run_psgi(@_) };
 
 It's important that the return value of C<.psgi> file is the code
-reference. See eg/dot-psgi directory for more examples of C<.psgi>
+reference. See C<eg/dot-psgi> directory for more examples of C<.psgi>
 files.
 
 =head2 plackup, Plack::Runner
@@ -107,7 +114,7 @@ reference.
 
 =head2 Plack::Test
 
-L<Plack::Test> is an unified interface to test your PSGI application
+L<Plack::Test> is a unified interface to test your PSGI application
 using standard L<HTTP::Request> and L<HTTP::Response> pair with simple
 callbacks.
 
@@ -151,7 +158,7 @@ types of modules.
 B<DO NOT USE> Plack:: namespace to build a new web application or a
 framework. It's like naming your application under CGI:: namespace if
 it's supposed to run on CGI and that is a really bad choice and
-confuse people.
+would confuse people badly.
 
 =head1 AUTHOR
 
@@ -159,7 +166,11 @@ Tatsuhiko Miyagawa
 
 =head1 COPYRIGHT
 
-Copyright 2009-2010 Tatsuhiko Miyagawa
+The following copyright notice applies to all the files provided in
+this distribution, including binary files, unless explicitly noted
+otherwise.
+
+Copyright 2009-2011 Tatsuhiko Miyagawa
 
 =head1 CONTRIBUTORS
 
@@ -199,7 +210,13 @@ Aaron Trevena
 
 =head1 SEE ALSO
 
-L<PSGI> L<http://plackperl.org/>
+The L<PSGI> specification upon which Plack is based.
+
+L<http://plackperl.org/>
+
+The Plack wiki: L<https://github.com/miyagawa/Plack/wiki>
+
+The Plack FAQ: L<https://github.com/miyagawa/Plack/wiki/Faq>
 
 =head1 LICENSE
 
